package com.zehong.system.service.track;

import java.util.List;
import com.zehong.system.domain.track.TProductDeviceTest;

/**
 * 设备检测Service接口
 * 
 * @author zehong
 * @date 2024-08-29
 */
public interface ITProductDeviceTestService 
{
    /**
     * 查询设备检测
     * 
     * @param id 设备检测ID
     * @return 设备检测
     */
    public TProductDeviceTest selectTProductDeviceTestById(Long id);

    /**
     * 查询设备检测列表
     * 
     * @param tProductDeviceTest 设备检测
     * @return 设备检测集合
     */
    public List<TProductDeviceTest> selectTProductDeviceTestList(TProductDeviceTest tProductDeviceTest);

    /**
     * 新增设备检测
     * 
     * @param tProductDeviceTest 设备检测
     * @return 结果
     */
    public int insertTProductDeviceTest(TProductDeviceTest tProductDeviceTest);

    /**
     * 修改设备检测
     * 
     * @param tProductDeviceTest 设备检测
     * @return 结果
     */
    public int updateTProductDeviceTest(TProductDeviceTest tProductDeviceTest);

    /**
     * 批量删除设备检测
     * 
     * @param ids 需要删除的设备检测ID
     * @return 结果
     */
    public int deleteTProductDeviceTestByIds(Long[] ids);

    /**
     * 删除设备检测信息
     * 
     * @param id 设备检测ID
     * @return 结果
     */
    public int deleteTProductDeviceTestById(Long id);
}
